changeset 5185:25cafe0a974d

merge
author Tom Gottfried <tom@intevation.de>
date Thu, 07 Mar 2013 11:25:31 +0100
parents e8e092c00791 (current diff) 0a83a796f7cf (diff)
children 801866a89ee0
files
diffstat 2 files changed, 20 insertions(+), 20 deletions(-) [+]
line wrap: on
line diff
--- a/flys-backend/src/main/java/de/intevation/flys/model/HWSLine.java	Thu Mar 07 11:20:52 2013 +0100
+++ b/flys-backend/src/main/java/de/intevation/flys/model/HWSLine.java	Thu Mar 07 11:25:31 2013 +0100
@@ -33,7 +33,7 @@
     private HWSKind  kind;
     private FedState fedState;
     private River    river;
-    private Integer  offical;
+    private Integer  official;
     private Integer  shoreSide;
     private String   name;
     private String   path;
@@ -93,22 +93,22 @@
 
 
     /**
-     * Get offical.
+     * Get official.
      *
      * @return offical as Integer.
      */
-    @Column(name = "offical")
-    public Integer getOffical() {
-        return offical;
+    @Column(name = "official")
+    public Integer getofficial() {
+        return official;
     }
 
     /**
-     * Set offical.
+     * Set official.
      *
      * @param offical the value to set.
      */
-    public void setOffical(Integer offical) {
-        this.offical = offical;
+    public void setofficial(Integer official) {
+        this.official = official;
     }
 
     /**
@@ -93,22 +93,22 @@
      *
-     * @return offical as Integer.
+     * @return official as Integer.
      */
@@ -93,22 +93,22 @@
      *
-     * @param offical the value to set.
+     * @param official the value to set.
      */
--- a/flys-backend/src/main/java/de/intevation/flys/model/HWSPoint.java	Thu Mar 07 11:20:52 2013 +0100
+++ b/flys-backend/src/main/java/de/intevation/flys/model/HWSPoint.java	Thu Mar 07 11:25:31 2013 +0100
@@ -28,7 +28,7 @@
     private HWSKind    kind;
     private FedState   fedState;
     private River      river;
-    private Integer    offical;
+    private Integer    official;
     private Integer    shoreSide;
     private String     name;
     private String     path;
@@ -94,22 +94,22 @@
 
 
     /**
-     * Get offical.
+     * Get official.
      *
      * @return offical as Integer.
      */
-    @Column(name = "offical")
-    public Integer getOffical() {
-        return offical;
+    @Column(name = "official")
+    public Integer getofficial() {
+        return official;
     }
 
     /**
-     * Set offical.
+     * Set official.
      *
      * @param offical the value to set.
      */
-    public void setOffical(Integer offical) {
-        this.offical = offical;
+    public void setofficial(Integer official) {
+        this.official = official;
     }
 
     /**
@@ -94,22 +94,22 @@
      *
-     * @return offical as Integer.
+     * @return official as Integer.
      */
@@ -94,22 +94,22 @@
      *
-     * @param offical the value to set.
+     * @param official the value to set.
      */

http://dive4elements.wald.intevation.org